:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.wp-block-legacy-widget__edit-form{
  background:#fff;
  border:1px solid #1e1e1e;
  border-radius:2px;
  max-height:calc(100vh - 2px);
  overflow-y:scroll;
  padding:11px;
}
.wp-block-legacy-widget__edit-form:not([hidden]){
  display:flow-root;
}
.wp-block-legacy-widget__edit-form .wp-block-legacy-widget__edit-form-title{
  color:#000;
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:14px;
  font-weight:600;
  margin:0 0 12px;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside{
  border:none;
  box-shadow:none;
  display:block;
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside p{
  margin:8px 0;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside label{
  font-size:13px;
  line-height:2.1;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside a,.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input,.wp-block-legacy-widget__edit-form .widget-inside.widget-inside label{
  color:#000;
  font-family:system-ui;
  font-weight:400;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=date],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=datetime-local],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=datetime],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=email],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=month],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=number],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=password],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=search],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=tel],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=text],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=time],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=url],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside input[type=week],.wp-block-legacy-widget__edit-form .widget-inside.widget-inside select{
  background-color:initial;
  border:1px solid #757575;
  border-radius:3px;
  box-shadow:none;
  box-sizing:border-box;
  color:#000;
  display:block;
  font-family:system-ui;
  font-size:13px;
  font-weight:400;
  line-height:1;
  margin:0;
  min-height:30px;
  padding-bottom:8px;
  padding-right:8px;
  padding-top:8px;
  width:100%;
}
.wp-block-legacy-widget__edit-form .widget-inside.widget-inside select{
  padding-right:4px;
}
.wp-block-legacy-widget__edit-form .widget.open,.wp-block-legacy-widget__edit-form .widget.open:focus-within{
  z-index:0;
}

.wp-block-legacy-widget__edit-form.wp-block-legacy-widget__edit-form,.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview{
  color:#000;
}

.wp-block-legacy-widget__edit-no-preview,.wp-block-legacy-widget__edit-preview{
  cursor:pointer;
}
.wp-block-legacy-widget__edit-no-preview:hover:after,.wp-block-legacy-widget__edit-preview:hover:after{
  border:1px solid #949494;
  border-radius:2px;
  bottom:0;
  content:"";
  left:0;
  position:absolute;
  right:0;
  top:0;
}

.wp-block-legacy-widget__edit-preview.is-offscreen{
  position:absolute;
  right:-9999px;
  top:0;
  width:100%;
}

.wp-block-legacy-widget__edit-preview-iframe{
  overflow:hidden;
  width:100%;
}

.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview{
  background:#f0f0f0;
  padding:8px 12px;
}
.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview,.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview h3,.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview p{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:13px;
}
.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview h3{
  font-size:14px;
  font-weight:600;
  margin:4px 0;
}
.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview.wp-block-legacy-widget__edit-no-preview p{
  margin:4px 0;
}

.wp-block-legacy-widget-inspector-card{
  padding:0 52px 16px 16px;
}

.interface-complementary-area .wp-block-legacy-widget-inspector-card__name{
  font-weight:500;
  margin:0 0 5px;
}

.is-selected .wp-block-legacy-widget__container{
  min-height:50px;
  padding:8px 12px;
}

.components-popover__content .wp-block-legacy-widget__edit-form{
  min-width:400px;
}

.wp-block-widget-group.has-child-selected:after{
  border:1px solid var(--wp-admin-theme-color);
  border-radius:2px;
  bottom:0;
  content:"";
  left:0;
  position:absolute;
  right:0;
  top:0;
}
.wp-block-widget-group .widget-title{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:18px;
  font-weight:600;
}

.wp-block-widget-group__placeholder .block-editor-inserter{
  width:100%;
}

.is-dark-theme .wp-block-widget-group__placeholder .block-editor-button-block-appender{
  box-shadow:inset 0 0 0 1px #1e1e1e;
  color:#1e1e1e;
}