body{margin:65px auto 24px;-webkit-box-shadow:none;box-shadow:none;background:#f1f1f1;padding:0;border:none}#wsal-logo{border:0;margin:0 0 24px;padding:0;text-align:center}#wsal-logo img{width:400px}.steps{display:flex;list-style-type:none;margin:0;padding:0 0 25px;text-align:center}.steps li{flex:1 0 auto;font-weight:700;margin:0 0 5px;color:#b4b9be;padding-bottom:15px;position:relative}.steps li.is-active{color:#009344}.steps li.is-active::before{border:4px solid #009344;background:#009344}.steps li::before{content:"";border:4px solid #b4b9be;border-radius:100%;width:4px;height:4px;position:absolute;bottom:0;left:50%;margin-left:-6px;margin-bottom:-8px;background:#b4b9be}.wsal-setup-content{box-shadow:0 1px 3px rgba(0, 0, 0, 0.13);padding:2em;margin:0 0 20px;background:#fff;overflow:hidden;zoom:1;text-align:left}.wsal-setup-content h4,.wsal-setup-content fieldset{line-height:1.5}.wsal-setup-content .addon-wrapper{border:1px solid #eee;padding:15px;display:flex;margin-bottom:15px}.wsal-setup-content .addon-wrapper:hover{border-color:#ccc}.wsal-setup-content .addon-wrapper img{align-self:center;max-width:200px;margin-right:15px}.wsal-setup-actions{text-align:center}.wsal-setup-actions .button{box-shadow:none;font-size:14px;height:auto;padding:8px 20px;min-width:12em;min-width:auto;transition:0.1s all linear}.wsal-setup-actions .button-primary{background-color:#009344;border-color:#009344;box-shadow:none;text-shadow:none;margin:0;opacity:1}.wsal-setup-actions .button-primary:hover,.wsal-setup-actions .button-primary:focus{background:#00ad50;border-color:#00ad50;box-shadow:none;color:#fff}.wsal-setup-footer{text-align:center}.wsal-setup-footer a{color:#009344;font-size:14px;text-decoration:none}.wsal-setup-form label[for="editor-users-box"],.wsal-setup-form label[for="editor-roles-box"],.wsal-setup-form label[for="exuser-query-box"],.wsal-setup-form label[for="exrole-query-box"],.wsal-setup-form label[for="ipaddr-query-box"]{display:inline-block;margin:5px 0}.wsal-setup-form label[for="editor-users-box"] span,.wsal-setup-form label[for="editor-roles-box"] span,.wsal-setup-form label[for="exuser-query-box"] span,.wsal-setup-form label[for="exrole-query-box"] span,.wsal-setup-form label[for="ipaddr-query-box"] span{display:inline-block;min-width:100px}.sectoken-user,.sectoken-role,.sectoken-ip,.sectoken-other{display:inline-block;border-width:1px;border-style:solid;padding:2px 4px;margin:2px 0 0 2px;border-radius:3px;cursor:default;line-height:1.3;font-size:14px}.sectoken-user a,.sectoken-role a,.sectoken-ip a,.sectoken-other a{text-decoration:none;font-size:12px;font-weight:bold;color:#FFF;margin-left:2px;background:#BBB;border-radius:25px;height:14px;display:inline-block;vertical-align:middle;width:14px;text-align:center;line-height:12px}.sectoken-user a:hover,.sectoken-role a:hover,.sectoken-ip a:hover,.sectoken-other a:hover{background:#FB9}.sectoken-other{display:table;border-collapse:separate}.sectoken-role{background:#EFE;border-color:#5B5}.sectoken-user{background:#EFF;border-color:#5BE}.sectoken-ip{background:#FFE;border-color:#ED5}.sectoken-other{background:#FFE;border-color:#ED5}p.description{font-size:13px;font-style:italic}