:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.edit-post-fullscreen-mode-close.components-button{
  display:none;
}
@media (min-width:782px){
  .edit-post-fullscreen-mode-close.components-button{
    align-items:center;
    align-self:stretch;
    background:#1e1e1e;
    border:none;
    border-radius:0;
    color:#fff;
    display:flex;
    height:60px;
    position:relative;
    width:60px;
  }
  .edit-post-fullscreen-mode-close.components-button:active{
    color:#fff;
  }
  .edit-post-fullscreen-mode-close.components-button:focus{
    box-shadow:none;
  }
  .edit-post-fullscreen-mode-close.components-button:before{
    border-radius:4px;
    bottom:10px;
    box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) #1e1e1e;
    content:"";
    display:block;
    left:9px;
    position:absolute;
    right:9px;
    top:9px;
    transition:box-shadow .1s ease;
  }
}
@media (min-width:782px) and (prefers-reduced-motion:reduce){
  .edit-post-fullscreen-mode-close.components-button:before{
    transition-delay:0s;
    transition-duration:0s;
  }
}
@media (min-width:782px){
  .edit-post-fullscreen-mode-close.components-button:hover:before{
    box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) #757575;
  }
  .edit-post-fullscreen-mode-close.components-button.has-icon:hover:before{
    box-shadow:none;
  }
  .edit-post-fullscreen-mode-close.components-button:focus:before{
    box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) #ffffff1a, inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  }
}
.edit-post-fullscreen-mode-close.components-button .edit-post-fullscreen-mode-close_site-icon{
  border-radius:2px;
  height:36px;
  margin-top:-1px;
  object-fit:cover;
  width:36px;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon{
  width:60px;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon svg{
  display:block;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon:after{
  content:none;
}

.edit-post-layout__metaboxes{
  clear:both;
  flex-shrink:0;
}

.components-editor-notices__snackbar{
  bottom:24px;
  left:0;
  padding-left:24px;
  padding-right:24px;
  position:fixed;
}

.edit-post-layout .components-editor-notices__snackbar{
  right:0;
}
@media (min-width:783px){
  .edit-post-layout .components-editor-notices__snackbar{
    right:160px;
  }
}
@media (min-width:783px){
  .auto-fold .edit-post-layout .components-editor-notices__snackbar{
    right:36px;
  }
}
@media (min-width:961px){
  .auto-fold .edit-post-layout .components-editor-notices__snackbar{
    right:160px;
  }
}
.folded .edit-post-layout .components-editor-notices__snackbar{
  right:0;
}
@media (min-width:783px){
  .folded .edit-post-layout .components-editor-notices__snackbar{
    right:36px;
  }
}

body.is-fullscreen-mode .edit-post-layout .components-editor-notices__snackbar{
  right:0 !important;
}

.edit-post-meta-boxes-area{
  position:relative;
}
.edit-post-meta-boxes-area .inside,.edit-post-meta-boxes-area__container{
  box-sizing:initial;
}
.edit-post-meta-boxes-area input,.edit-post-meta-boxes-area textarea{
  box-sizing:border-box;
}
.edit-post-meta-boxes-area .postbox-header{
  border-bottom:0;
  border-top:1px solid #ddd;
}
.edit-post-meta-boxes-area #poststuff{
  margin:0 auto;
  min-width:auto;
  padding-top:0;
}
.edit-post-meta-boxes-area #poststuff .stuffbox>h3,.edit-post-meta-boxes-area #poststuff h2.hndle,.edit-post-meta-boxes-area #poststuff h3.hndle{
  box-sizing:border-box;
  color:inherit;
  font-weight:600;
  outline:none;
  padding:0 24px;
  position:relative;
  width:100%;
}
.edit-post-meta-boxes-area .postbox{
  border:0;
  color:inherit;
  margin-bottom:0;
}
.edit-post-meta-boxes-area .postbox>.inside{
  color:inherit;
  margin:0;
  padding:0 24px 24px;
}
.edit-post-meta-boxes-area .postbox .handlediv{
  height:44px;
  width:44px;
}
.edit-post-meta-boxes-area.is-loading:before{
  background:#0000;
  bottom:0;
  content:"";
  left:0;
  position:absolute;
  right:0;
  top:0;
  z-index:1;
}
.edit-post-meta-boxes-area .components-spinner{
  left:20px;
  position:absolute;
  top:10px;
  z-index:5;
}
.edit-post-meta-boxes-area .is-hidden{
  display:none;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]{
  border:1px solid #757575;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]:checked{
  background:#fff;
  border-color:#757575;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]:before{
  margin:-3px -4px;
}

.edit-post-meta-boxes-area__clear{
  clear:both;
}

.edit-post-welcome-guide,.edit-template-welcome-guide{
  width:312px;
}
.edit-post-welcome-guide__image,.edit-template-welcome-guide__image{
  background:#00a0d2;
  margin:0 0 16px;
}
.edit-post-welcome-guide__image>img,.edit-template-welcome-guide__image>img{
  display:block;
  max-width:100%;
  object-fit:cover;
}
.edit-post-welcome-guide__heading,.edit-template-welcome-guide__heading{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:24px;
  line-height:1.4;
  margin:16px 0;
  padding:0 32px;
}
.edit-post-welcome-guide__text,.edit-template-welcome-guide__text{
  font-size:13px;
  line-height:1.4;
  margin:0 0 24px;
  padding:0 32px;
}
.edit-post-welcome-guide__inserter-icon,.edit-template-welcome-guide__inserter-icon{
  margin:0 4px;
  vertical-align:text-top;
}

.edit-template-welcome-guide .components-button svg{
  fill:#fff;
}
@keyframes edit-post__fade-in-animation{
  0%{
    opacity:0;
  }
  to{
    opacity:1;
  }
}
body.js.block-editor-page{
  background:#fff;
}
body.js.block-editor-page #wpcontent{
  padding-right:0;
}
body.js.block-editor-page #wpbody-content{
  padding-bottom:0;
}
body.js.block-editor-page #wpbody-content>div:not(.block-editor):not(#screen-meta),body.js.block-editor-page #wpfooter{
  display:none;
}
body.js.block-editor-page .a11y-speak-region{
  right:-1px;
  top:-1px;
}
body.js.block-editor-page ul#adminmenu a.wp-has-current-submenu:after,body.js.block-editor-page ul#adminmenu>li.current>a.current:after{
  border-left-color:#fff;
}
body.js.block-editor-page .media-frame select.attachment-filters:last-of-type{
  max-width:100%;
  width:auto;
}

.block-editor-page #wpwrap{
  overflow-y:auto;
}
@media (min-width:782px){
  .block-editor-page #wpwrap{
    overflow-y:initial;
  }
}

.edit-post-visual-editor.is-iframed,.editor-header,.editor-post-publish-panel,.editor-sidebar,.editor-text-editor{
  box-sizing:border-box;
}
.edit-post-visual-editor.is-iframed *,.edit-post-visual-editor.is-iframed :after,.edit-post-visual-editor.is-iframed :before,.editor-header *,.editor-header :after,.editor-header :before,.editor-post-publish-panel *,.editor-post-publish-panel :after,.editor-post-publish-panel :before,.editor-sidebar *,.editor-sidebar :after,.editor-sidebar :before,.editor-text-editor *,.editor-text-editor :after,.editor-text-editor :before{
  box-sizing:inherit;
}

@media (min-width:600px){
  .block-editor__container{
    bottom:0;
    left:0;
    min-height:calc(100vh - 46px);
    position:absolute;
    right:0;
    top:0;
  }
}
@media (min-width:782px){
  .block-editor__container{
    min-height:calc(100vh - 32px);
  }
  body.is-fullscreen-mode .block-editor__container{
    min-height:100vh;
  }
}
.block-editor__container img{
  height:auto;
  max-width:100%;
}

body.admin-color-light{
  --wp-admin-theme-color:#0085ba;
  --wp-admin-theme-color--rgb:0, 133, 186;
  --wp-admin-theme-color-darker-10:#0073a1;
  --wp-admin-theme-color-darker-10--rgb:0, 115, 161;
  --wp-admin-theme-color-darker-20:#006187;
  --wp-admin-theme-color-darker-20--rgb:0, 97, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-light{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-modern{
  --wp-admin-theme-color:#3858e9;
  --wp-admin-theme-color--rgb:56, 88, 233;
  --wp-admin-theme-color-darker-10:#2145e6;
  --wp-admin-theme-color-darker-10--rgb:33, 69, 230;
  --wp-admin-theme-color-darker-20:#183ad6;
  --wp-admin-theme-color-darker-20--rgb:24, 58, 214;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-modern{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-blue{
  --wp-admin-theme-color:#096484;
  --wp-admin-theme-color--rgb:9, 100, 132;
  --wp-admin-theme-color-darker-10:#07526c;
  --wp-admin-theme-color-darker-10--rgb:7, 82, 108;
  --wp-admin-theme-color-darker-20:#064054;
  --wp-admin-theme-color-darker-20--rgb:6, 64, 84;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-blue{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-coffee{
  --wp-admin-theme-color:#46403c;
  --wp-admin-theme-color--rgb:70, 64, 60;
  --wp-admin-theme-color-darker-10:#383330;
  --wp-admin-theme-color-darker-10--rgb:56, 51, 48;
  --wp-admin-theme-color-darker-20:#2b2724;
  --wp-admin-theme-color-darker-20--rgb:43, 39, 36;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-coffee{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ectoplasm{
  --wp-admin-theme-color:#523f6d;
  --wp-admin-theme-color--rgb:82, 63, 109;
  --wp-admin-theme-color-darker-10:#46365d;
  --wp-admin-theme-color-darker-10--rgb:70, 54, 93;
  --wp-admin-theme-color-darker-20:#3a2c4d;
  --wp-admin-theme-color-darker-20--rgb:58, 44, 77;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ectoplasm{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-midnight{
  --wp-admin-theme-color:#e14d43;
  --wp-admin-theme-color--rgb:225, 77, 67;
  --wp-admin-theme-color-darker-10:#dd382d;
  --wp-admin-theme-color-darker-10--rgb:221, 56, 45;
  --wp-admin-theme-color-darker-20:#d02c21;
  --wp-admin-theme-color-darker-20--rgb:208, 44, 33;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-midnight{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ocean{
  --wp-admin-theme-color:#627c83;
  --wp-admin-theme-color--rgb:98, 124, 131;
  --wp-admin-theme-color-darker-10:#576e74;
  --wp-admin-theme-color-darker-10--rgb:87, 110, 116;
  --wp-admin-theme-color-darker-20:#4c6066;
  --wp-admin-theme-color-darker-20--rgb:76, 96, 102;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ocean{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-sunrise{
  --wp-admin-theme-color:#dd823b;
  --wp-admin-theme-color--rgb:221, 130, 59;
  --wp-admin-theme-color-darker-10:#d97426;
  --wp-admin-theme-color-darker-10--rgb:217, 116, 38;
  --wp-admin-theme-color-darker-20:#c36922;
  --wp-admin-theme-color-darker-20--rgb:195, 105, 34;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-sunrise{
    --wp-admin-border-width-focus:1.5px;
  }
}