@charset "UTF-8";
:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.components-panel__header.interface-complementary-area-header__small{
  background:#fff;
  padding-left:4px;
}
.components-panel__header.interface-complementary-area-header__small .interface-complementary-area-header__small-title{
  margin:0;
  overflow:hidden;
  text-overflow:ellipsis;
  white-space:nowrap;
  width:100%;
}
@media (min-width:782px){
  .components-panel__header.interface-complementary-area-header__small{
    display:none;
  }
}

.interface-complementary-area-header{
  background:#fff;
  gap:8px;
  padding-left:12px;
}
.interface-complementary-area-header .interface-complementary-area-header__title{
  margin:0;
}
.interface-complementary-area-header .components-button.has-icon{
  display:none;
  margin-right:auto;
}
.interface-complementary-area-header .components-button.has-icon~.components-button{
  margin-right:0;
}
@media (min-width:782px){
  .interface-complementary-area-header .components-button.has-icon{
    display:flex;
  }
}

.interface-complementary-area{
  background:#fff;
  color:#1e1e1e;
  height:100%;
  overflow:auto;
}
@media (min-width:600px){
  .interface-complementary-area{
    -webkit-overflow-scrolling:touch;
  }
}
@media (min-width:782px){
  .interface-complementary-area{
    width:280px;
  }
}
.interface-complementary-area .components-panel{
  border:none;
  position:relative;
  z-index:0;
}
.interface-complementary-area .components-panel__header{
  position:sticky;
  top:0;
  z-index:1;
}
.interface-complementary-area .components-panel__header.editor-sidebar__panel-tabs{
  top:48px;
}
@media (min-width:782px){
  .interface-complementary-area .components-panel__header.editor-sidebar__panel-tabs{
    top:0;
  }
}
.interface-complementary-area p:not(.components-base-control__help){
  margin-top:0;
}
.interface-complementary-area h2{
  color:#1e1e1e;
  font-size:13px;
  font-weight:500;
  margin-bottom:1.5em;
}
.interface-complementary-area h3{
  color:#1e1e1e;
  font-size:11px;
  font-weight:500;
  margin-bottom:1.5em;
  text-transform:uppercase;
}
.interface-complementary-area hr{
  border-bottom:1px solid #f0f0f0;
  border-top:none;
  margin:1.5em 0;
}
.interface-complementary-area div.components-toolbar,.interface-complementary-area div.components-toolbar-group{
  box-shadow:none;
  margin-bottom:1.5em;
}
.interface-complementary-area div.components-toolbar-group:last-child,.interface-complementary-area div.components-toolbar:last-child{
  margin-bottom:0;
}
.interface-complementary-area .block-editor-skip-to-selected-block:focus{
  bottom:10px;
  left:10px;
  right:auto;
  top:auto;
}

.interface-complementary-area__fill{
  height:100%;
}

@media (min-width:782px){
  body.js.is-fullscreen-mode{
    height:calc(100% + 32px);
    margin-top:-32px;
  }
  body.js.is-fullscreen-mode #adminmenumain,body.js.is-fullscreen-mode #wpadminbar{
    display:none;
  }
  body.js.is-fullscreen-mode #wpcontent,body.js.is-fullscreen-mode #wpfooter{
    margin-right:0;
  }
}

html.interface-interface-skeleton__html-container{
  position:fixed;
  width:100%;
}
@media (min-width:782px){
  html.interface-interface-skeleton__html-container:not(:has(.is-zoom-out)){
    position:static;
    width:auto;
  }
}

.interface-interface-skeleton{
  bottom:0;
  display:flex;
  flex-direction:row;
  height:auto;
  left:0;
  max-height:100%;
  position:fixed;
  top:46px;
}
@media (min-width:783px){
  .interface-interface-skeleton{
    top:32px;
  }
  .is-fullscreen-mode .interface-interface-skeleton{
    top:0;
  }
}

.interface-interface-skeleton__editor{
  display:flex;
  flex:0 1 100%;
  flex-direction:column;
  overflow:hidden;
}

.interface-interface-skeleton{
  right:0;
}
@media (min-width:783px){
  .interface-interface-skeleton{
    right:160px;
  }
}
@media (min-width:783px){
  .auto-fold .interface-interface-skeleton{
    right:36px;
  }
}
@media (min-width:961px){
  .auto-fold .interface-interface-skeleton{
    right:160px;
  }
}
.folded .interface-interface-skeleton{
  right:0;
}
@media (min-width:783px){
  .folded .interface-interface-skeleton{
    right:36px;
  }
}

body.is-fullscreen-mode .interface-interface-skeleton{
  right:0 !important;
}

.interface-interface-skeleton__body{
  display:flex;
  flex-grow:1;
  overflow:auto;
  overscroll-behavior-y:none;
  position:relative;
}
@media (min-width:782px){
  .has-footer .interface-interface-skeleton__body{
    padding-bottom:25px;
  }
}

.interface-interface-skeleton__content{
  display:flex;
  flex-direction:column;
  flex-grow:1;
  overflow:auto;
  z-index:20;
}
@media (min-width:782px){
  .interface-interface-skeleton__content{
    z-index:auto;
  }
}

.interface-interface-skeleton__secondary-sidebar,.interface-interface-skeleton__sidebar{
  background:#fff;
  bottom:0;
  color:#1e1e1e;
  flex-shrink:0;
  position:absolute;
  right:0;
  top:0;
  width:auto;
  z-index:100000;
}
@media (min-width:782px){
  .interface-interface-skeleton__secondary-sidebar,.interface-interface-skeleton__sidebar{
    position:relative !important;
  }
}

.interface-interface-skeleton__sidebar{
  border-top:1px solid #e0e0e0;
  overflow:hidden;
}
@media (min-width:782px){
  .interface-interface-skeleton__sidebar{
    box-shadow:1px 1px 0 0 rgba(0,0,0,.133);
    outline:1px solid #0000;
  }
}

.interface-interface-skeleton__secondary-sidebar{
  border-top:1px solid #e0e0e0;
  left:0;
}
@media (min-width:782px){
  .interface-interface-skeleton__secondary-sidebar{
    box-shadow:-1px 1px 0 0 rgba(0,0,0,.133);
    outline:1px solid #0000;
  }
}

.interface-interface-skeleton__header{
  box-shadow:0 1px 0 0 rgba(0,0,0,.133);
  color:#1e1e1e;
  flex-shrink:0;
  height:auto;
  outline:1px solid #0000;
  z-index:30;
}

.interface-interface-skeleton__footer{
  background-color:#fff;
  border-top:1px solid #e0e0e0;
  bottom:0;
  color:#1e1e1e;
  display:none;
  flex-shrink:0;
  height:auto;
  position:absolute;
  right:0;
  width:100%;
  z-index:90;
}
@media (min-width:782px){
  .interface-interface-skeleton__footer{
    display:flex;
  }
}
.interface-interface-skeleton__footer .block-editor-block-breadcrumb{
  align-items:center;
  background:#fff;
  display:flex;
  font-size:13px;
  height:24px;
  padding:0 18px;
  z-index:30;
}

.interface-interface-skeleton__actions{
  background:#fff;
  bottom:auto;
  color:#1e1e1e;
  left:0;
  position:fixed !important;
  right:auto;
  top:-9999em;
  width:100vw;
  z-index:100000;
}
@media (min-width:782px){
  .interface-interface-skeleton__actions{
    width:280px;
  }
}
.interface-interface-skeleton__actions:focus,.interface-interface-skeleton__actions:focus-within{
  bottom:0;
  top:auto;
}
.is-entity-save-view-open .interface-interface-skeleton__actions:focus,.is-entity-save-view-open .interface-interface-skeleton__actions:focus-within{
  top:46px;
}
@media (min-width:782px){
  .is-entity-save-view-open .interface-interface-skeleton__actions:focus,.is-entity-save-view-open .interface-interface-skeleton__actions:focus-within{
    border-right:1px solid #ddd;
    top:32px;
  }
  .is-fullscreen-mode .is-entity-save-view-open .interface-interface-skeleton__actions:focus,.is-fullscreen-mode .is-entity-save-view-open .interface-interface-skeleton__actions:focus-within{
    top:0;
  }
}

.interface-pinned-items{
  display:flex;
  gap:8px;
}
.interface-pinned-items .components-button{
  display:none;
  margin:0;
}
.interface-pinned-items .components-button[aria-controls="edit-post:block"],.interface-pinned-items .components-button[aria-controls="edit-post:document"],.interface-pinned-items .components-button[aria-controls="edit-site:block-inspector"],.interface-pinned-items .components-button[aria-controls="edit-site:template"]{
  display:flex;
}
.interface-pinned-items .components-button svg{
  max-height:24px;
  max-width:24px;
}
@media (min-width:600px){
  .interface-pinned-items .components-button{
    display:flex;
  }
}

.editor-autocompleters__user .editor-autocompleters__no-avatar:before{
  content:"";
  font:normal 20px/1 dashicons;
  margin-left:5px;
  vertical-align:middle;
}
.editor-autocompleters__user .editor-autocompleters__user-avatar{
  flex-grow:0;
  flex-shrink:0;
  height:24px;
  margin-left:8px;
  max-width:none;
  width:24px;
}
.editor-autocompleters__user .editor-autocompleters__user-name{
  flex-grow:1;
  flex-shrink:0;
  max-width:200px;
  overflow:hidden;
  text-overflow:ellipsis;
  white-space:nowrap;
}
.editor-autocompleters__user .editor-autocompleters__user-slug{
  color:#757575;
  flex-grow:0;
  flex-shrink:0;
  margin-right:8px;
  max-width:100px;
  overflow:none;
  text-overflow:ellipsis;
  white-space:nowrap;
}
.editor-autocompleters__user:hover .editor-autocompleters__user-slug{
  color:var(--wp-admin-theme-color);
}

.editor-block-manager__no-results{
  font-style:italic;
  padding:24px 0;
  text-align:center;
}

.editor-block-manager__search{
  margin:16px 0;
}

.editor-block-manager__disabled-blocks-count{
  background-color:#fff;
  border:1px solid #ddd;
  border-width:1px 0;
  box-shadow:32px 0 0 0 #fff,-32px 0 0 0 #fff;
  padding:8px;
  position:sticky;
  text-align:center;
  top:-5px;
  z-index:2;
}
.editor-block-manager__disabled-blocks-count~.editor-block-manager__results .editor-block-manager__category-title{
  top:31px;
}
.editor-block-manager__disabled-blocks-count .is-link{
  margin-right:12px;
}

.editor-block-manager__category{
  margin:0 0 24px;
}

.editor-block-manager__category-title{
  background-color:#fff;
  padding:16px 0;
  position:sticky;
  top:-4px;
  z-index:1;
}
.editor-block-manager__category-title .components-checkbox-control__label{
  font-weight:600;
}

.editor-block-manager__checklist{
  margin-top:0;
}

.editor-block-manager__category-title,.editor-block-manager__checklist-item{
  border-bottom:1px solid #ddd;
}

.editor-block-manager__checklist-item{
  align-items:center;
  display:flex;
  justify-content:space-between;
  margin-bottom:0;
  padding:8px 16px 8px 0;
}
.components-modal__content .editor-block-manager__checklist-item.components-checkbox-control__input-container{
  margin:0 8px;
}
.editor-block-manager__checklist-item .block-editor-block-icon{
  margin-left:10px;
  fill:#1e1e1e;
}

.editor-block-manager__results{
  border-top:1px solid #ddd;
}

.editor-block-manager__disabled-blocks-count+.editor-block-manager__results{
  border-top-width:0;
}

.editor-collapsible-block-toolbar{
  align-items:center;
  display:flex;
  height:60px;
  overflow:hidden;
}
.editor-collapsible-block-toolbar .block-editor-block-contextual-toolbar{
  background:#0000;
  border-bottom:0;
  height:100%;
}
.editor-collapsible-block-toolbar .block-editor-block-toolbar{
  height:100%;
  padding-top:15px;
}
.editor-collapsible-block-toolbar .block-editor-block-toolbar .components-button:not(.block-editor-block-mover-button){
  height:32px;
}
.editor-collapsible-block-toolbar:after{
  background-color:#ddd;
  content:"";
  height:24px;
  margin-left:7px;
  width:1px;
}
.editor-collapsible-block-toolbar .components-toolbar,.editor-collapsible-block-toolbar .components-toolbar-group{
  border-left:none;
  position:relative;
}
.editor-collapsible-block-toolbar .components-toolbar-group:after,.editor-collapsible-block-toolbar .components-toolbar:after{
  background-color:#ddd;
  content:"";
  height:24px;
  left:-1px;
  position:absolute;
  top:4px;
  width:1px;
}
.editor-collapsible-block-toolbar .components-toolbar .components-toolbar-group.components-toolbar-group:after,.editor-collapsible-block-toolbar .components-toolbar-group .components-toolbar-group.components-toolbar-group:after{
  display:none;
}
.editor-collapsible-block-toolbar .block-editor-block-mover.is-horizontal .block-editor-block-mover-button{
  height:32px;
  overflow:visible;
}
@media (min-width:600px){
  .editor-collapsible-block-toolbar .block-editor-block-mover:not(.is-horizontal) .block-editor-block-mover__move-button-container{
    height:40px;
    position:relative;
    top:-5px;
  }
}
.editor-collapsible-block-toolbar.is-collapsed{
  display:none;
}

.editor-collapsible-block-toolbar__toggle{
  margin-right:2px;
}

.editor-create-template-part-modal{
  z-index:1000001;
}
@media (min-width:600px){
  .editor-create-template-part-modal .components-modal__frame{
    max-width:500px;
  }
}

.editor-create-template-part-modal__area-radio-group{
  border:1px solid #757575;
  border-radius:2px;
  width:100%;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio{
  display:block;
  height:100%;
  padding:12px;
  text-align:right;
  width:100%;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-primary:hover,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-secondary:hover{
  background-color:inherit;
  border-bottom:1px solid #757575;
  border-radius:0;
  margin:0;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-primary:hover:not(:focus),.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-secondary:hover:not(:focus),.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio:not(:focus){
  box-shadow:none;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-primary:hover:focus,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-secondary:hover:focus,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio:focus{
  border-bottom:1px solid #fff;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-primary:hover:last-of-type,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio.is-secondary:hover:last-of-type,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio:last-of-type{
  border-bottom:none;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio:not(:hover),.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio[aria-checked=true]{
  color:#1e1e1e;
  cursor:auto;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio:not(:hover) .editor-create-template-part-modal__option-label div,.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio[aria-checked=true] .editor-create-template-part-modal__option-label div{
  color:#949494;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio .editor-create-template-part-modal__option-label{
  padding-top:4px;
  white-space:normal;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio .editor-create-template-part-modal__option-label div{
  font-size:12px;
  padding-top:4px;
}
.editor-create-template-part-modal__area-radio-group .components-button.editor-create-template-part-modal__area-radio .editor-create-template-part-modal__checkbox{
  margin-right:auto;
  min-width:24px;
}

.editor-content-only-settings-menu__description{
  min-width:235px;
  padding:8px;
}

.editor-blog-title-dropdown__content .components-popover__content{
  min-width:320px;
  padding:16px;
}

.editor-document-bar{
  align-items:center;
  background:#f0f0f0;
  border-radius:4px;
  display:flex;
  height:32px;
  justify-content:space-between;
  min-width:0;
  width:min(100%, 416px);
}
.editor-document-bar:hover{
  background-color:#e0e0e0;
}
.editor-document-bar .components-button{
  border-radius:4px;
  transition:all .1s ease-out;
}
@media (prefers-reduced-motion:reduce){
  .editor-document-bar .components-button{
    transition-delay:0s;
    transition-duration:0s;
  }
}
.editor-document-bar .components-button:hover{
  background:#e0e0e0;
}
@media (min-width:960px){
  .editor-document-bar{
    width:min(100%, 450px);
  }
}

.editor-document-bar__command{
  color:var(--wp-block-synced-color);
  flex-grow:1;
  overflow:hidden;
}

.editor-document-bar__title{
  align-items:center;
  color:#1e1e1e;
  display:flex;
  flex-grow:1;
  gap:4px;
  justify-content:center;
  overflow:hidden;
}
@media (min-width:782px){
  .editor-document-bar__title{
    padding-right:24px;
  }
}
.editor-document-bar.is-global .editor-document-bar__title{
  color:var(--wp-block-synced-color);
}
.editor-document-bar__title .block-editor-block-icon{
  flex-shrink:0;
  min-width:24px;
}
.editor-document-bar__title h1{
  color:currentColor;
  max-width:70%;
  overflow:hidden;
  text-overflow:ellipsis;
  white-space:nowrap;
}

.editor-document-bar__shortcut{
  color:#2f2f2f;
  display:none;
  min-width:24px;
}
@media (min-width:782px){
  .editor-document-bar__shortcut{
    display:initial;
  }
}

.editor-document-bar__back.components-button.has-icon.has-text{
  color:#757575;
  flex-shrink:0;
  gap:0;
  min-width:36px;
  position:absolute;
  z-index:1;
}
.editor-document-bar__back.components-button.has-icon.has-text:hover{
  background-color:initial;
  color:#1e1e1e;
}

.document-outline{
  margin:20px 0;
}
.document-outline ul{
  margin:0;
  padding:0;
}

.document-outline__item{
  display:flex;
  margin:4px 0;
}
.document-outline__item a{
  text-decoration:none;
}
.document-outline__item .document-outline__emdash:before{
  color:#ddd;
  margin-left:4px;
}
.document-outline__item.is-h2 .document-outline__emdash:before{
  content:"—";
}
.document-outline__item.is-h3 .document-outline__emdash:before{
  content:"——";
}
.document-outline__item.is-h4 .document-outline__emdash:before{
  content:"———";
}
.document-outline__item.is-h5 .document-outline__emdash:before{
  content:"————";
}
.document-outline__item.is-h6 .document-outline__emdash:before{
  content:"—————";
}

.document-outline__button{
  align-items:flex-start;
  background:none;
  border:none;
  border-radius:2px;
  color:#1e1e1e;
  cursor:pointer;
  display:flex;
  margin:0 -1px 0 0;
  padding:2px 1px 2px 5px;
  text-align:right;
}
.document-outline__button:disabled{
  cursor:default;
}
.document-outline__button:focus{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  outline:2px solid #0000;
}

.document-outline__level{
  background:#ddd;
  border-radius:3px;
  color:#1e1e1e;
  font-size:13px;
  margin-left:4px;
  padding:1px 6px;
}
.is-invalid .document-outline__level{
  background:#f0b849;
}

.document-outline__item-content{
  padding:1px 0;
}

.editor-document-outline.has-no-headings{
  color:#757575;
  text-align:center;
}
.editor-document-outline.has-no-headings>svg{
  margin-top:28px;
}
.editor-document-outline.has-no-headings>p{
  padding-left:32px;
  padding-right:32px;
}

.editor-document-tools{
  align-items:center;
  display:inline-flex;
}
.editor-document-tools .editor-document-tools__left>.editor-history__redo,.editor-document-tools .editor-document-tools__left>.editor-history__undo{
  display:none;
}
@media (min-width:782px){
  .editor-document-tools .editor-document-tools__left>.editor-history__redo,.editor-document-tools .editor-document-tools__left>.editor-history__undo{
    display:inline-flex;
  }
}
.editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle{
  display:inline-flex;
}
.editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle svg{
  transition:transform .2s cubic-bezier(.165, .84, .44, 1);
}
@media (prefers-reduced-motion:reduce){
  .editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle svg{
    transition-delay:0s;
    transition-duration:0s;
  }
}
.editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle.is-pressed svg{
  transform:rotate(-45deg);
}
.editor-document-tools .block-editor-list-view{
  display:none;
}
@media (min-width:600px){
  .editor-document-tools .block-editor-list-view{
    display:flex;
  }
}
.editor-document-tools .editor-document-tools__left>.components-button.has-icon,.editor-document-tools .editor-document-tools__left>.components-dropdown>.components-button.has-icon{
  height:32px;
  min-width:32px;
  padding:4px;
}
.editor-document-tools .editor-document-tools__left>.components-button.has-icon.is-pressed,.editor-document-tools .editor-document-tools__left>.components-dropdown>.components-button.has-icon.is-pressed{
  background:#1e1e1e;
}
.editor-document-tools .editor-document-tools__left>.components-button.has-icon:focus:not(:disabled),.editor-document-tools .editor-document-tools__left>.components-dropdown>.components-button.has-icon:focus:not(:disabled){
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color), inset 0 0 0 1px #fff;
  outline:1px solid #0000;
}
.editor-document-tools .editor-document-tools__left>.components-button.has-icon:before,.editor-document-tools .editor-document-tools__left>.components-dropdown>.components-button.has-icon:before{
  display:none;
}

.editor-document-tools__left{
  align-items:center;
  display:inline-flex;
  gap:8px;
  margin-left:8px;
  padding-right:16px;
}

.editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle.has-icon{
  height:32px;
  min-width:32px;
  padding:0;
  width:32px;
}
.show-icon-labels .editor-document-tools .editor-document-tools__left>.editor-document-tools__inserter-toggle.has-icon{
  height:32px;
  padding:0 8px;
  width:auto;
}

.show-icon-labels .editor-document-tools__left>*+*{
  margin-right:8px;
}

.editor-editor-interface .entities-saved-states__panel-header{
  height:61px;
}

.editor-editor-interface .interface-interface-skeleton__content{
  isolation:isolate;
}

.editor-visual-editor{
  flex:1 0 auto;
}

.components-editor-notices__dismissible,.components-editor-notices__pinned{
  color:#1e1e1e;
  left:0;
  position:relative;
  right:0;
  top:0;
}
.components-editor-notices__dismissible .components-notice,.components-editor-notices__pinned .components-notice{
  border-bottom:1px solid #0003;
  box-sizing:border-box;
  min-height:60px;
  padding:0 12px;
}
.components-editor-notices__dismissible .components-notice .components-notice__dismiss,.components-editor-notices__pinned .components-notice .components-notice__dismiss{
  margin-top:12px;
}

.entities-saved-states__panel-header{
  background:#fff;
  border-bottom:1px solid #ddd;
  box-sizing:border-box;
  height:60px;
  padding-left:8px;
  padding-right:8px;
}

.entities-saved-states__text-prompt{
  padding:16px 16px 4px;
}
.entities-saved-states__text-prompt .entities-saved-states__text-prompt--header{
  display:block;
  margin-bottom:12px;
}

.entities-saved-states__description-heading{
  font-size:13px;
}

.entities-saved-states__changes{
  color:#757575;
  font-size:12px;
  list-style:disc;
  margin:8px 16px 0;
}
.entities-saved-states__changes li{
  margin-bottom:4px;
}

.editor-error-boundary{
  box-shadow:0 .7px 1px #00000026,0 2.7px 3.8px -.2px #00000026,0 5.5px 7.8px -.3px #00000026,-.1px 11.5px 16.4px -.5px #00000026;
  margin:60px auto auto;
  max-width:780px;
  padding:20px;
}

.editor-header{
  align-items:center;
  background:#fff;
  display:flex;
  flex-wrap:wrap;
  height:60px;
  justify-content:space-between;
  max-width:100vw;
}
@media (min-width:280px){
  .editor-header{
    flex-wrap:nowrap;
  }
}

.editor-header__toolbar{
  align-items:center;
  display:flex;
  flex-grow:3;
  flex-shrink:8;
  overflow:hidden;
  padding:2px 0;
}
@media (min-width:782px){
  .editor-header__toolbar{
    padding-left:var(--wp-admin-border-width-focus);
  }
}
.editor-header__toolbar .table-of-contents{
  display:none;
}
@media (min-width:600px){
  .editor-header__toolbar .table-of-contents{
    display:block;
  }
}

.editor-header__center{
  display:flex;
  flex-grow:1;
  justify-content:center;
  min-width:0;
}
.editor-header__center.is-collapsed{
  display:none;
}
.editor-header__settings{
  align-items:center;
  display:inline-flex;
  flex-wrap:nowrap;
  gap:8px;
  padding-left:4px;
}
@media (min-width:600px){
  .editor-header__settings{
    padding-left:8px;
  }
}
.show-icon-labels .editor-header .components-button.has-icon,.show-icon-labels.interface-pinned-items .components-button.has-icon{
  width:auto;
}
.show-icon-labels .editor-header .components-button.has-icon svg,.show-icon-labels.interface-pinned-items .components-button.has-icon svg{
  display:none;
}
.show-icon-labels .editor-header .components-button.has-icon:after,.show-icon-labels.interface-pinned-items .components-button.has-icon:after{
  content:attr(aria-label);
}
.show-icon-labels .editor-header .components-button.has-icon[aria-disabled=true],.show-icon-labels.interface-pinned-items .components-button.has-icon[aria-disabled=true]{
  background-color:initial;
}
.show-icon-labels .editor-header .is-tertiary:active,.show-icon-labels.interface-pinned-items .is-tertiary:active{
  background-color:initial;
  box-shadow:0 0 0 1.5px var(--wp-admin-theme-color);
}
.show-icon-labels .editor-header .components-button.has-icon.button-toggle svg,.show-icon-labels.interface-pinned-items .components-button.has-icon.button-toggle svg{
  display:block;
}
.show-icon-labels .editor-header .components-button.has-icon.button-toggle:after,.show-icon-labels.interface-pinned-items .components-button.has-icon.button-toggle:after{
  content:none;
}
.show-icon-labels .editor-header .components-menu-items-choice .components-menu-items__item-icon.components-menu-items__item-icon,.show-icon-labels.interface-pinned-items .components-menu-items-choice .components-menu-items__item-icon.components-menu-items__item-icon{
  display:block;
}
.show-icon-labels .editor-header .editor-document-tools__inserter-toggle.editor-document-tools__inserter-toggle,.show-icon-labels .editor-header .interface-pinned-items .components-button,.show-icon-labels.interface-pinned-items .editor-document-tools__inserter-toggle.editor-document-tools__inserter-toggle,.show-icon-labels.interface-pinned-items .interface-pinned-items .components-button{
  padding-left:8px;
  padding-right:8px;
}
@media (min-width:600px){
  .show-icon-labels .editor-header .editor-document-tools__inserter-toggle.editor-document-tools__inserter-toggle,.show-icon-labels .editor-header .interface-pinned-items .components-button,.show-icon-labels.interface-pinned-items .editor-document-tools__inserter-toggle.editor-document-tools__inserter-toggle,.show-icon-labels.interface-pinned-items .interface-pinned-items .components-button{
    padding-left:12px;
    padding-right:12px;
  }
}
.show-icon-labels .editor-header .editor-post-save-draft.editor-post-save-draft:after,.show-icon-labels .editor-header .editor-post-saved-state.editor-post-saved-state:after,.show-icon-labels.interface-pinned-items .editor-post-save-draft.editor-post-save-draft:after,.show-icon-labels.interface-pinned-items .editor-post-saved-state.editor-post-saved-state:after{
  content:none;
}

.show-icon-labels .editor-header__toolbar .block-editor-block-mover{
  border-right:none;
}
.show-icon-labels .editor-header__toolbar .block-editor-block-mover:before{
  background-color:#ddd;
  content:"";
  height:24px;
  margin-right:8px;
  margin-top:4px;
  width:1px;
}
.show-icon-labels .editor-header__toolbar .block-editor-block-mover .block-editor-block-mover__move-button-container:before{
  background:#ddd;
  right:calc(50% + 1px);
  width:calc(100% - 24px);
}

.show-icon-labels.interface-pinned-items{
  border-bottom:1px solid #ccc;
  display:block;
  margin:0 -12px;
  padding:6px 12px 12px;
}
.show-icon-labels.interface-pinned-items>.components-button.has-icon{
  justify-content:flex-start;
  margin:0;
  padding:6px 8px 6px 6px;
  width:14.625rem;
}
.show-icon-labels.interface-pinned-items>.components-button.has-icon[aria-expanded=true] svg{
  display:block;
  max-width:24px;
}
.show-icon-labels.interface-pinned-items>.components-button.has-icon[aria-expanded=false]{
  padding-right:40px;
}
.show-icon-labels.interface-pinned-items>.components-button.has-icon svg{
  margin-left:8px;
}

@media (min-width:600px){
  .editor-header__post-preview-button{
    display:none;
  }
}

.editor-editor-interface.is-distraction-free .interface-interface-skeleton__header{
  border-bottom:none;
}
.editor-editor-interface.is-distraction-free .editor-header{
  background-color:#fff;
  border-bottom:1px solid #e0e0e0;
  position:absolute;
  width:100%;
}
.editor-editor-interface.is-distraction-free .editor-header>.edit-post-header__settings>.edit-post-header__post-preview-button{
  visibility:hidden;
}
.editor-editor-interface.is-distraction-free .editor-header>.editor-header__settings>.editor-preview-dropdown,.editor-editor-interface.is-distraction-free .editor-header>.editor-header__settings>.interface-pinned-items,.editor-editor-interface.is-distraction-free .editor-header>.editor-header__toolbar .editor-document-tools__document-overview-toggle{
  display:none;
}
.editor-editor-interface.is-distraction-free .interface-interface-skeleton__header:focus-within{
  opacity:1 !important;
}
.editor-editor-interface.is-distraction-free .interface-interface-skeleton__header:focus-within div{
  transform:translateX(0) translateZ(0) !important;
}
.editor-editor-interface.is-distraction-free .components-editor-notices__dismissible{
  position:absolute;
  z-index:35;
}

.components-popover.more-menu-dropdown__content{
  z-index:99998;
}

.editor-inserter-sidebar{
  box-sizing:border-box;
  display:flex;
  flex-direction:column;
  height:100%;
}
.editor-inserter-sidebar *,.editor-inserter-sidebar :after,.editor-inserter-sidebar :before{
  box-sizing:inherit;
}

.editor-inserter-sidebar__content{
  height:calc(100% - 44px);
}
@media (min-width:782px){
  .editor-inserter-sidebar__content{
    height:100%;
  }
}

.editor-keyboard-shortcut-help-modal__section{
  margin:0 0 2rem;
}
.editor-keyboard-shortcut-help-modal__section-title{
  font-size:.9rem;
  font-weight:600;
}
.editor-keyboard-shortcut-help-modal__shortcut{
  align-items:baseline;
  border-top:1px solid #ddd;
  display:flex;
  margin-bottom:0;
  padding:.6rem 0;
}
.editor-keyboard-shortcut-help-modal__shortcut:last-child{
  border-bottom:1px solid #ddd;
}
.editor-keyboard-shortcut-help-modal__shortcut:empty{
  display:none;
}
.editor-keyboard-shortcut-help-modal__shortcut-term{
  font-weight:600;
  margin:0 1rem 0 0;
  text-align:left;
}
.editor-keyboard-shortcut-help-modal__shortcut-description{
  flex:1;
  flex-basis:auto;
  margin:0;
}
.editor-keyboard-shortcut-help-modal__shortcut-key-combination{
  background:none;
  display:block;
  margin:0;
  padding:0;
}
.editor-keyboard-shortcut-help-modal__shortcut-key-combination+.editor-keyboard-shortcut-help-modal__shortcut-key-combination{
  margin-top:10px;
}
.editor-keyboard-shortcut-help-modal__shortcut-key{
  border-radius:8%;
  margin:0 .2rem;
  padding:.25rem .5rem;
}
.editor-keyboard-shortcut-help-modal__shortcut-key:last-child{
  margin:0 .2rem 0 0;
}

.editor-list-view-sidebar{
  display:flex;
  flex-direction:column;
  height:100%;
}
@media (min-width:782px){
  .editor-list-view-sidebar{
    width:350px;
  }
}
.editor-list-view-sidebar .editor-list-view-sidebar__header{
  border-bottom:1px solid #ddd;
  display:flex;
}
.editor-list-view-sidebar .editor-list-view-sidebar__close-button{
  align-self:center;
  background:#fff;
  margin-left:12px;
  order:1;
}

.editor-list-view-sidebar__tabs-tablist{
  box-sizing:border-box;
  flex-grow:1;
}

.editor-list-view-sidebar__tabs-tab{
  margin-bottom:-1px;
  width:50%;
}

.editor-list-view-sidebar__tabs-tabpanel{
  height:calc(100% - 47px);
}

.editor-list-view-sidebar__list-view-container>.document-outline,.editor-list-view-sidebar__list-view-panel-content{
  height:100%;
  overflow:auto;
  padding:4px;
  scrollbar-color:#0000 #0000;
  scrollbar-gutter:stable both-edges;
  scrollbar-gutter:auto;
  scrollbar-width:thin;
  will-change:transform;
}
.editor-list-view-sidebar__list-view-container>.document-outline::-webkit-scrollbar,.editor-list-view-sidebar__list-view-panel-content::-webkit-scrollbar{
  height:12px;
  width:12px;
}
.editor-list-view-sidebar__list-view-container>.document-outline::-webkit-scrollbar-track,.editor-list-view-sidebar__list-view-panel-content::-webkit-scrollbar-track{
  background-color:initial;
}
.editor-list-view-sidebar__list-view-container>.document-outline::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-panel-content::-webkit-scrollbar-thumb{
  background-clip:padding-box;
  background-color:initial;
  border:3px solid #0000;
  border-radius:8px;
}
.editor-list-view-sidebar__list-view-container>.document-outline:focus-within::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-container>.document-outline:focus::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-container>.document-outline:hover::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-panel-content:focus-within::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-panel-content:focus::-webkit-scrollbar-thumb,.editor-list-view-sidebar__list-view-panel-content:hover::-webkit-scrollbar-thumb{
  background-color:#949494;
}
.editor-list-view-sidebar__list-view-container>.document-outline:focus,.editor-list-view-sidebar__list-view-container>.document-outline:focus-within,.editor-list-view-sidebar__list-view-container>.document-outline:hover,.editor-list-view-sidebar__list-view-panel-content:focus,.editor-list-view-sidebar__list-view-panel-content:focus-within,.editor-list-view-sidebar__list-view-panel-content:hover{
  scrollbar-color:#949494 #0000;
}
@media (hover:none){
  .editor-list-view-sidebar__list-view-container>.document-outline,.editor-list-view-sidebar__list-view-panel-content{
    scrollbar-color:#949494 #0000;
  }
}

.editor-list-view-sidebar__list-view-container{
  display:flex;
  flex-direction:column;
  height:100%;
}

.editor-list-view-sidebar__tab-panel{
  height:100%;
}

.editor-list-view-sidebar__outline{
  border-bottom:1px solid #ddd;
  display:flex;
  flex-direction:column;
  gap:8px;
  padding:16px;
}
.editor-list-view-sidebar__outline>div>span:first-child{
  display:inline-block;
  width:90px;
}
.editor-list-view-sidebar__outline>div>span{
  color:#757575;
  font-size:12px;
  line-height:1.4;
}

.editor-post-order__panel,.editor-post-parent__panel{
  padding-top:8px;
}
.editor-post-order__panel .editor-post-panel__row-control>div,.editor-post-parent__panel .editor-post-panel__row-control>div{
  width:100%;
}

.editor-post-order__panel-dialog .editor-post-order,.editor-post-order__panel-dialog .editor-post-parent,.editor-post-parent__panel-dialog .editor-post-order,.editor-post-parent__panel-dialog .editor-post-parent{
  margin:8px;
}
.editor-post-order__panel-dialog .components-popover__content,.editor-post-parent__panel-dialog .components-popover__content{
  min-width:320px;
}

.editor-post-author__panel{
  padding-top:8px;
}

.editor-post-author__panel .editor-post-panel__row-control>div{
  width:100%;
}

.editor-post-author__panel-dialog .editor-post-author{
  margin:8px;
  min-width:248px;
}

.editor-action-modal{
  z-index:1000001;
}

.editor-post-card-panel__content{
  flex-grow:1;
}
.editor-post-card-panel__title{
  width:100%;
}
.editor-post-card-panel__title.editor-post-card-panel__title{
  align-items:center;
  column-gap:8px;
  display:flex;
  flex-wrap:wrap;
  margin:0;
  padding:2px 0;
  row-gap:4px;
  word-break:break-word;
}
.editor-post-card-panel__icon{
  flex:0 0 24px;
  height:24px;
  width:24px;
}
.editor-post-card-panel__header{
  display:flex;
  justify-content:space-between;
}
.editor-post-card-panel.has-description .editor-post-card-panel__header{
  margin-bottom:8px;
}

.editor-post-card-panel__icon.is-sync{
  fill:var(--wp-block-synced-color);
}

.editor-post-card-panel__title-badge{
  background:#f0f0f0;
  border-radius:2px;
  color:#757575;
  display:inline-block;
  flex-shrink:0;
  font-size:12px;
  font-weight:400;
  line-height:20px;
  padding:0 4px;
}

.editor-post-content-information{
  color:#757575;
}
.editor-post-content-information .components-text{
  color:inherit;
}

.editor-post-discussion__panel-dialog .editor-post-discussion{
  margin:8px;
  min-width:248px;
}
.editor-post-discussion__panel-dialog .editor-post-discussion .components-radio-control__option{
  align-items:flex-start;
}
.editor-post-discussion__panel-dialog .editor-post-discussion .components-radio-control__label .components-text{
  display:block;
  margin-top:4px;
}

.editor-post-discussion__panel-toggle .components-text{
  color:inherit;
}

.editor-post-discussion__panel-dialog .components-popover__content{
  min-width:320px;
}

.editor-post-excerpt__textarea{
  margin-bottom:10px;
  width:100%;
}

.editor-post-excerpt__dropdown__content .components-popover__content{
  min-width:320px;
  padding:16px;
}

.editor-post-featured-image{
  padding:0;
}
.editor-post-featured-image .components-spinner{
  margin-right:-9px;
  margin-top:-9px;
  position:absolute;
  right:50%;
  top:50%;
}

.editor-post-featured-image__container{
  position:relative;
}
.editor-post-featured-image__container:focus .editor-post-featured-image__actions,.editor-post-featured-image__container:focus-within .editor-post-featured-image__actions,.editor-post-featured-image__container:hover .editor-post-featured-image__actions{
  opacity:1;
}
.editor-post-featured-image__container .components-drop-zone__content{
  border-radius:2px;
}
.editor-post-featured-image__container:has(.editor-post-featured-image__toggle) .components-drop-zone .components-drop-zone__content-inner{
  align-items:center;
  display:flex;
  gap:8px;
}
.editor-post-featured-image__container:has(.editor-post-featured-image__toggle) .components-drop-zone .components-drop-zone__content-inner .components-drop-zone__content-icon{
  margin:0;
}

.editor-post-featured-image__preview,.editor-post-featured-image__toggle{
  box-shadow:0 0 0 0 var(--wp-admin-theme-color);
  display:flex;
  justify-content:center;
  min-height:40px;
  outline-offset:-1px;
  overflow:hidden;
  padding:0;
  transition:all .1s ease-out;
  width:100%;
}
@media (prefers-reduced-motion:reduce){
  .editor-post-featured-image__preview,.editor-post-featured-image__toggle{
    transition-delay:0s;
    transition-duration:0s;
  }
}

.editor-post-featured-image__preview{
  height:auto;
  outline:1px solid #0000001a;
}
.editor-post-featured-image__preview .editor-post-featured-image__preview-image{
  aspect-ratio:2/1;
  object-fit:cover;
  object-position:50% 50%;
  width:100%;
}

.editor-post-featured-image__toggle{
  border-radius:2px;
  box-shadow:inset 0 0 0 1px #ccc;
  height:100%;
  line-height:20px;
  padding:8px 0;
  text-align:center;
}

.editor-post-featured-image__actions{
  bottom:0;
  opacity:0;
  padding:8px;
  position:absolute;
  transition:opacity 50ms ease-out;
}
@media (prefers-reduced-motion:reduce){
  .editor-post-featured-image__actions{
    transition-delay:0s;
    transition-duration:0s;
  }
}

.editor-post-featured-image__action{
  -webkit-backdrop-filter:blur(16px) saturate(180%);
          backdrop-filter:blur(16px) saturate(180%);
  background:#ffffffbf;
  flex-grow:1;
  justify-content:center;
}

[class].editor-post-format__suggestion{
  margin:4px 0 0;
}

.editor-post-format__dialog .editor-post-format__dialog-content{
  margin:8px;
  min-width:248px;
}

.editor-post-format__options .components-base-control__field>.components-v-stack{
  gap:12px;
}

.editor-post-last-edited-panel{
  color:#757575;
}
.editor-post-last-edited-panel .components-text{
  color:inherit;
}

.editor-post-last-revision__title{
  font-weight:500;
  width:100%;
}

.editor-post-last-revision__title.components-button.has-icon{
  height:100%;
  justify-content:space-between;
}
.editor-post-last-revision__title.components-button.has-icon:active,.editor-post-last-revision__title.components-button.has-icon:hover{
  background:#f0f0f0;
}
.editor-post-last-revision__title.components-button.has-icon:focus{
  border-radius:0;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
}

.components-panel__body.is-opened.editor-post-last-revision__panel{
  height:48px;
  padding:0;
}
.components-panel__body.is-opened.editor-post-last-revision__panel .editor-post-last-revision__title.components-button.components-button{
  padding:16px;
}

.editor-private-post-last-revision__button{
  display:inline-block;
}

.editor-post-locked-modal__buttons{
  margin-top:24px;
}

.editor-post-locked-modal__avatar{
  border-radius:2px;
  margin-top:16px;
  min-width:auto !important;
}

.editor-post-panel__row{
  align-items:flex-start !important;
  justify-content:flex-start !important;
  min-height:32px;
  width:100%;
}

.editor-post-panel__row-label{
  align-items:center;
  display:flex;
  flex-shrink:0;
  -webkit-hyphens:auto;
          hyphens:auto;
  line-height:20px;
  min-height:32px;
  padding:6px 0;
  width:30%;
}

.editor-post-panel__row-control{
  align-items:center;
  display:flex;
  flex-grow:1;
  min-height:32px;
}
.editor-post-panel__row-control .components-button{
  height:auto;
  max-width:100%;
  min-height:32px;
  text-align:right;
  text-wrap:balance;
  text-wrap:pretty;
  white-space:normal;
}
.editor-post-panel__row-control .components-dropdown{
  max-width:100%;
}

.editor-post-panel__section{
  padding:16px;
}

.editor-post-publish-panel__content{
  min-height:calc(100% - 144px);
}
.editor-post-publish-panel__content>.components-spinner{
  display:block;
  margin:100px auto 0;
}

.editor-post-publish-panel__header{
  align-content:space-between;
  align-items:center;
  background:#fff;
  border-bottom:1px solid #ddd;
  display:flex;
  height:61px;
  padding-left:16px;
  padding-right:16px;
}
.editor-post-publish-panel__header .components-button{
  justify-content:center;
  width:100%;
}
.editor-post-publish-panel__header .has-icon{
  margin-right:auto;
  width:auto;
}

.components-site-card{
  align-items:center;
  display:flex;
  margin:16px 0;
}

.components-site-icon{
  border:none;
  border-radius:2px;
  height:36px;
  margin-left:12px;
  width:36px;
}

.components-site-name{
  display:block;
  font-size:14px;
}

.components-site-home{
  color:#757575;
  display:block;
  font-size:12px;
}

.editor-post-publish-panel__header-cancel-button,.editor-post-publish-panel__header-publish-button{
  flex:1;
}
@media (min-width:480px){
  .editor-post-publish-panel__header-cancel-button,.editor-post-publish-panel__header-publish-button{
    max-width:160px;
  }
}

.editor-post-publish-panel__header-publish-button{
  justify-content:center;
  padding-left:4px;
}

.editor-post-publish-panel__header-cancel-button{
  padding-right:4px;
}

.editor-post-publish-panel__header-published{
  flex-grow:1;
}

.editor-post-publish-panel__footer{
  padding:16px;
}

.components-button.editor-post-publish-panel__toggle.is-primary{
  align-items:center;
  display:inline-flex;
}
.components-button.editor-post-publish-panel__toggle.is-primary.is-busy .dashicon{
  display:none;
}
.components-button.editor-post-publish-panel__toggle.is-primary .dashicon{
  margin-left:-4px;
}

.editor-post-publish-panel__link{
  font-weight:400;
  padding-right:4px;
}

.editor-post-publish-panel__prepublish{
  padding:16px;
}
.editor-post-publish-panel__prepublish strong{
  color:#1e1e1e;
}
.editor-post-publish-panel__prepublish .components-panel__body{
  background:#fff;
  margin-left:-16px;
  margin-right:-16px;
}
.editor-post-publish-panel__prepublish .editor-post-visibility__dialog-legend{
  display:none;
}
.editor-post-publish-panel__prepublish .components-panel__body-title .components-button{
  align-items:flex-start;
  text-wrap:balance;
  text-wrap:pretty;
}

.post-publish-panel__postpublish .components-panel__body{
  border-bottom:1px solid #e0e0e0;
  border-top:none;
}

.post-publish-panel__postpublish-buttons{
  align-content:space-between;
  display:flex;
  flex-wrap:wrap;
  gap:16px;
}
.post-publish-panel__postpublish-buttons .components-button{
  flex:1;
  justify-content:center;
}
.post-publish-panel__postpublish-buttons .components-clipboard-button{
  width:100%;
}

.post-publish-panel__postpublish-post-address-container{
  align-items:flex-end;
  display:flex;
  margin-bottom:16px;
}
.post-publish-panel__postpublish-post-address-container .post-publish-panel__postpublish-post-address{
  flex:1;
}
.post-publish-panel__postpublish-post-address-container input[readonly]{
  background:#f0f0f0;
  border-color:#ccc;
  height:36px;
  overflow:hidden;
  padding:12px;
  text-overflow:ellipsis;
}

.post-publish-panel__postpublish-post-address__copy-button-wrap{
  flex-shrink:0;
  margin-right:16px;
}

.post-publish-panel__postpublish-header{
  font-weight:500;
}

.post-publish-panel__postpublish-subheader{
  margin:0 0 8px;
}

.post-publish-panel__tip{
  color:#f0b849;
}

@media screen and (max-width:782px){
  .post-publish-panel__postpublish-post-address__button-wrap .components-button{
    height:40px;
  }
}
.editor-post-publish-panel{
  background:#fff;
  bottom:0;
  left:0;
  overflow:auto;
  position:fixed;
  right:0;
  top:46px;
  z-index:100001;
}
@media (min-width:782px){
  .editor-post-publish-panel{
    animation:editor-post-publish-panel__slide-in-animation .1s forwards;
    border-right:1px solid #ddd;
    right:auto;
    top:32px;
    transform:translateX(-100%);
    width:281px;
    z-index:99998;
  }
}
@media (min-width:782px) and (prefers-reduced-motion:reduce){
  .editor-post-publish-panel{
    animation-delay:0s;
    animation-duration:1ms;
  }
}
@media (min-width:782px){
  body.is-fullscreen-mode .editor-post-publish-panel{
    top:0;
  }
  [role=region]:focus .editor-post-publish-panel{
    transform:translateX(0);
  }
}

@keyframes editor-post-publish-panel__slide-in-animation{
  to{
    transform:translateX(0);
  }
}
.editor-post-saved-state{
  align-items:center;
  color:#757575;
  display:flex;
  overflow:hidden;
  padding:12px 4px;
  white-space:nowrap;
  width:28px;
}
.editor-post-saved-state.is-saved[aria-disabled=true],.editor-post-saved-state.is-saved[aria-disabled=true]:hover,.editor-post-saved-state.is-saving[aria-disabled=true],.editor-post-saved-state.is-saving[aria-disabled=true]:hover{
  background:#0000;
  color:#757575;
}
.editor-post-saved-state svg{
  display:inline-block;
  flex:0 0 auto;
  fill:currentColor;
  margin-left:8px;
}
@media (min-width:600px){
  .editor-post-saved-state{
    padding:8px 12px;
    text-indent:inherit;
    width:auto;
  }
  .editor-post-saved-state svg{
    margin-left:0;
  }
}

.editor-post-save-draft.has-text.has-icon svg{
  margin-left:0;
}

.editor-post-schedule__panel-dropdown{
  width:100%;
}

.editor-post-schedule__dialog .components-popover__content{
  min-width:320px;
  padding:16px;
}

.editor-post-slug{
  align-items:stretch;
  display:flex;
  flex-direction:column;
}

.editor-post-status{
  max-width:100%;
}
.editor-post-status.is-read-only{
  padding:6px 12px;
}

.editor-change-status__password-fieldset,.editor-change-status__publish-date-wrapper{
  border-top:1px solid #e0e0e0;
  padding-top:16px;
}

.editor-change-status__content .components-popover__content{
  min-width:320px;
  padding:16px;
}
.editor-change-status__content .editor-change-status__options .components-base-control__field>.components-v-stack{
  gap:12px;
}
.editor-change-status__content .editor-change-status__options .components-radio-control__option{
  align-items:flex-start;
}
.editor-change-status__content .editor-change-status__options label .components-text{
  display:block;
  margin-top:4px;
}
.editor-change-status__content .editor-change-status__password-legend{
  margin-bottom:8px;
  padding:0;
}

.editor-post-sticky__toggle-control{
  padding:6px 12px;
}

.editor-post-sync-status__value{
  padding:6px 12px 6px 0;
}

.editor-post-taxonomies__hierarchical-terms-list{
  margin-right:-6px;
  margin-top:-6px;
  max-height:14em;
  overflow:auto;
  padding-right:6px;
  padding-top:6px;
}

.editor-post-taxonomies__hierarchical-terms-choice{
  margin-bottom:8px;
}
.editor-post-taxonomies__hierarchical-terms-choice:last-child{
  margin-bottom:4px;
}

.editor-post-taxonomies__hierarchical-terms-subchoices{
  margin-right:16px;
  margin-top:8px;
}

.editor-post-taxonomies__flat-term-most-used .editor-post-taxonomies__flat-term-most-used-label{
  margin-bottom:4px;
}

.editor-post-taxonomies__flat-term-most-used-list{
  margin:0;
}
.editor-post-taxonomies__flat-term-most-used-list li{
  display:inline-block;
  margin-left:8px;
}
.editor-post-taxonomies__flat-term-most-used-list .components-button{
  font-size:12px;
}

.editor-post-template__swap-template-modal{
  z-index:1000001;
}

.editor-post-template__swap-template-modal-content .block-editor-block-patterns-list{
  column-count:2;
  column-gap:24px;
  padding-top:2px;
}
@media (min-width:782px){
  .editor-post-template__swap-template-modal-content .block-editor-block-patterns-list{
    column-count:3;
  }
}
@media (min-width:1280px){
  .editor-post-template__swap-template-modal-content .block-editor-block-patterns-list{
    column-count:4;
  }
}
.editor-post-template__swap-template-modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item{
  break-inside:avoid-column;
}

.editor-post-template__dropdown .components-popover__content{
  min-width:240px;
}
.editor-post-template__dropdown .components-button.is-pressed,.editor-post-template__dropdown .components-button.is-pressed:hover{
  background:inherit;
  color:inherit;
}

@media (min-width:782px){
  .editor-post-template__create-form{
    width:320px;
  }
}

.editor-post-template__classic-theme-dropdown{
  padding:8px;
}

textarea.editor-post-text-editor{
  border:1px solid #949494;
  border-radius:0;
  box-shadow:none;
  display:block;
  font-family:Menlo,Consolas,monaco,monospace;
  font-size:16px !important;
  line-height:2.4;
  margin:0;
  min-height:200px;
  overflow:hidden;
  padding:16px;
  resize:none;
  transition:border .1s ease-out,box-shadow .1s linear;
  width:100%;
}
@media (prefers-reduced-motion:reduce){
  textarea.editor-post-text-editor{
    transition-delay:0s;
    transition-duration:0s;
  }
}
@media (min-width:600px){
  textarea.editor-post-text-editor{
    font-size:15px !important;
    padding:24px;
  }
}
textarea.editor-post-text-editor:focus{
  border-color:var(--wp-admin-theme-color);
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  position:relative;
}
textarea.editor-post-text-editor::-webkit-input-placeholder{
  color:#1e1e1e9e;
}
textarea.editor-post-text-editor::-moz-placeholder{
  color:#1e1e1e9e;
  opacity:1;
}
textarea.editor-post-text-editor:-ms-input-placeholder{
  color:#1e1e1e9e;
}

.editor-post-title.is-raw-text{
  margin-bottom:24px;
  margin-top:2px;
  max-width:none;
}

.editor-post-url__panel-dropdown{
  width:100%;
}

.editor-post-url__panel-dialog .editor-post-url{
  margin:8px;
  min-width:248px;
}
.editor-post-url__link{
  color:#757575;
  direction:ltr;
  margin-top:4px;
  word-break:break-word;
}
.editor-post-url__link-slug{
  font-weight:600;
}

.editor-post-url__input input.components-input-control__input{
  padding-inline-start:0 !important;
}

.editor-post-url__panel-toggle{
  word-break:break-word;
}

.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]{
  border:1px solid #1e1e1e;
  border-radius:2px;
  border-radius:50%;
  box-shadow:0 0 0 #0000;
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:16px;
  height:24px;
  line-height:normal;
  margin-left:12px;
  margin-top:2px;
  max-width:24px;
  min-width:24px;
  padding:6px 8px;
  transition:box-shadow .1s linear;
  transition:none;
  width:24px;
}
@media (prefers-reduced-motion:reduce){
  .editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]{
    transition-delay:0s;
    transition-duration:0s;
  }
}
@media (min-width:600px){
  .editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]{
    font-size:13px;
    line-height:normal;
  }
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:focus{
  border-color:var(--wp-admin-theme-color);
  box-shadow:0 0 0 .5px var(--wp-admin-theme-color);
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]::-webkit-input-placeholder{
  color:#1e1e1e9e;
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]::-moz-placeholder{
  color:#1e1e1e9e;
  opacity:1;
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:-ms-input-placeholder{
  color:#1e1e1e9e;
}
@media (min-width:600px){
  .editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]{
    height:20px;
    max-width:20px;
    min-width:20px;
    width:20px;
  }
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:checked:before{
  background-color:#fff;
  border:4px solid #fff;
  box-sizing:inherit;
  height:8px;
  margin:0;
  transform:translate(-7px, 7px);
  width:8px;
}
@media (min-width:600px){
  .editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:checked:before{
    transform:translate(-5px, 5px);
  }
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:focus{
  box-shadow:0 0 0 2px #fff, 0 0 0 4px var(--wp-admin-theme-color);
  outline:2px solid #0000;
}
.editor-post-visibility__fieldset .editor-post-visibility__radio[type=radio]:checked{
  background:var(--wp-admin-theme-color);
  border-color:var(--wp-admin-theme-color);
}
.editor-post-visibility__fieldset .editor-post-visibility__info{
  color:#757575;
  margin-right:36px;
  margin-top:.5em;
}
@media (min-width:600px){
  .editor-post-visibility__fieldset .editor-post-visibility__info{
    margin-right:32px;
  }
}
.editor-post-visibility__fieldset .editor-post-visibility__choice:last-child .editor-post-visibility__info{
  margin-bottom:0;
}
.editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]{
  border:1px solid #949494;
  border-radius:2px;
  box-shadow:0 0 0 #0000;
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:16px;
  line-height:normal;
  margin-right:32px;
  padding:6px 8px;
  transition:box-shadow .1s linear;
  width:calc(100% - 32px);
}
@media (prefers-reduced-motion:reduce){
  .editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]{
    transition-delay:0s;
    transition-duration:0s;
  }
}
@media (min-width:600px){
  .editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]{
    font-size:13px;
    line-height:normal;
  }
}
.editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]:focus{
  border-color:var(--wp-admin-theme-color);
  box-shadow:0 0 0 .5px var(--wp-admin-theme-color);
  outline:2px solid #0000;
}
.editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]::-webkit-input-placeholder{
  color:#1e1e1e9e;
}
.editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]::-moz-placeholder{
  color:#1e1e1e9e;
  opacity:1;
}
.editor-post-visibility__fieldset .editor-post-visibility__password .editor-post-visibility__password-input[type=text]:-ms-input-placeholder{
  color:#1e1e1e9e;
}

.editor-posts-per-page-dropdown__content .components-popover__content{
  min-width:320px;
  padding:16px;
}

.editor-post-trash.components-button{
  flex-grow:1;
  justify-content:center;
}

.editor-preview-dropdown__button-external{
  display:flex;
  justify-content:space-between;
  width:100%;
}

.editor-resizable-editor.is-resizable{
  margin:0 auto;
  overflow:visible;
}

.editor-resizable-editor__resize-handle{
  appearance:none;
  background:none;
  border:0;
  border-radius:2px;
  bottom:0;
  cursor:ew-resize;
  height:100px;
  margin:auto 0;
  outline:none;
  padding:0;
  position:absolute;
  top:0;
  width:12px;
}
.editor-resizable-editor__resize-handle:after{
  background-color:#75757566;
  border-radius:2px;
  bottom:16px;
  content:"";
  left:0;
  position:absolute;
  right:4px;
  top:16px;
  width:4px;
}
.editor-resizable-editor__resize-handle.is-left{
  right:-18px;
}
.editor-resizable-editor__resize-handle.is-right{
  left:-18px;
}
.editor-resizable-editor__resize-handle:active,.editor-resizable-editor__resize-handle:focus,.editor-resizable-editor__resize-handle:hover{
  opacity:1;
}
.editor-resizable-editor__resize-handle:active:after,.editor-resizable-editor__resize-handle:focus:after,.editor-resizable-editor__resize-handle:hover:after{
  background-color:var(--wp-admin-theme-color);
}

.editor-layout__toggle-entities-saved-states-panel,.editor-layout__toggle-publish-panel,.editor-layout__toggle-sidebar-panel{
  background-color:#fff;
  border:1px dotted #ddd;
  bottom:auto;
  box-sizing:border-box;
  display:flex;
  height:auto !important;
  justify-content:center;
  left:0;
  padding:24px;
  position:fixed !important;
  right:auto;
  top:-9999em;
  width:280px;
  z-index:100000;
}

.interface-interface-skeleton__actions:focus .editor-layout__toggle-entities-saved-states-panel,.interface-interface-skeleton__actions:focus .editor-layout__toggle-publish-panel,.interface-interface-skeleton__actions:focus-within .editor-layout__toggle-entities-saved-states-panel,.interface-interface-skeleton__actions:focus-within .editor-layout__toggle-publish-panel{
  bottom:0;
  top:auto;
}

.editor-start-page-options__modal-content .block-editor-block-patterns-list{
  column-count:2;
  column-gap:24px;
}
@media (min-width:782px){
  .editor-start-page-options__modal-content .block-editor-block-patterns-list{
    column-count:3;
  }
}
@media (min-width:1280px){
  .editor-start-page-options__modal-content .block-editor-block-patterns-list{
    column-count:4;
  }
}
.editor-start-page-options__modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item{
  break-inside:avoid-column;
  margin-bottom:24px;
}
.editor-start-page-options__modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item .block-editor-block-preview__container{
  min-height:100px;
}
.editor-start-page-options__modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item .block-editor-block-preview__content{
  width:100%;
}

.editor-start-template-options__modal .editor-start-template-options__modal__actions{
  background-color:#fff;
  border-top:1px solid #ddd;
  bottom:0;
  height:92px;
  margin-left:-32px;
  margin-right:-32px;
  padding-left:32px;
  padding-right:32px;
  position:absolute;
  width:100%;
  z-index:1;
}
.editor-start-template-options__modal .block-editor-block-patterns-list{
  padding-bottom:92px;
}

.editor-start-template-options__modal-content .block-editor-block-patterns-list{
  column-count:2;
  column-gap:24px;
}
@media (min-width:782px){
  .editor-start-template-options__modal-content .block-editor-block-patterns-list{
    column-count:3;
  }
}
@media (min-width:1280px){
  .editor-start-template-options__modal-content .block-editor-block-patterns-list{
    column-count:4;
  }
}
.editor-start-template-options__modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item{
  break-inside:avoid-column;
}
.editor-start-template-options__modal-content .block-editor-block-patterns-list .block-editor-block-patterns-list__list-item .block-editor-block-patterns-list__item-title{
  display:none;
}

.components-panel__header.editor-sidebar__panel-tabs{
  padding-left:12px;
  padding-right:0;
}
.components-panel__header.editor-sidebar__panel-tabs .components-button.has-icon{
  height:24px;
  min-width:24px;
  padding:0;
}
@media (min-width:782px){
  .components-panel__header.editor-sidebar__panel-tabs .components-button.has-icon{
    display:flex;
  }
}

.editor-post-summary .components-v-stack:empty{
  display:none;
}

.editor-site-discussion-dropdown__content .components-popover__content{
  min-width:320px;
  padding:16px;
}

.editor-site-discussion__options .components-radio-control__option{
  align-items:flex-start;
}
.editor-site-discussion__options label .components-text{
  display:block;
  margin-top:4px;
}

.table-of-contents__popover.components-popover .components-popover__content{
  min-width:380px;
}

.components-popover.table-of-contents__popover{
  z-index:99998;
}

.table-of-contents__popover .components-popover__content{
  padding:16px;
}
@media (min-width:600px){
  .table-of-contents__popover .components-popover__content{
    max-height:calc(100vh - 120px);
    overflow-y:auto;
  }
}
.table-of-contents__popover hr{
  margin:10px -16px 0;
}

.table-of-contents__wrapper:focus:before{
  bottom:0;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  content:"";
  display:block;
  left:0;
  pointer-events:none;
  position:absolute;
  right:0;
  top:0;
}

.table-of-contents__counts{
  display:flex;
  flex-wrap:wrap;
  margin:-8px 0 0;
}

.table-of-contents__count{
  color:#1e1e1e;
  display:flex;
  flex-basis:33%;
  flex-direction:column;
  font-size:13px;
  margin-bottom:0;
  margin-top:8px;
  padding-left:8px;
}
.table-of-contents__count:nth-child(4n){
  padding-left:0;
}

.table-of-contents__number,.table-of-contents__popover .word-count{
  color:#1e1e1e;
  font-size:21px;
  font-weight:400;
  line-height:30px;
}

.table-of-contents__title{
  display:block;
  font-size:15px;
  font-weight:600;
  margin-top:20px;
}
.editor-template-areas__list,.editor-template-areas__list>li{
  margin:0;
}
.editor-template-areas__item{
  width:100%;
}
.editor-template-areas__item.components-button.has-icon{
  padding:0;
}

h3.components-heading.editor-template-areas__title{
  font-weight:500;
  margin:0 0 8px;
}

.editor-text-editor{
  background-color:#fff;
  flex-grow:1;
  position:relative;
  width:100%;
}
.editor-text-editor .editor-post-title.is-raw-text textarea,.editor-text-editor .editor-post-title:not(.is-raw-text){
  border:1px solid #949494;
  border-radius:0;
  font-family:Menlo,Consolas,monaco,monospace;
  font-size:2.5em;
  font-weight:400;
  line-height:1.4;
  max-width:none;
  padding:16px;
}
@media (min-width:600px){
  .editor-text-editor .editor-post-title.is-raw-text textarea,.editor-text-editor .editor-post-title:not(.is-raw-text){
    padding:24px;
  }
}
.editor-text-editor .editor-post-title.is-raw-text textarea:focus,.editor-text-editor .editor-post-title:not(.is-raw-text):focus{
  border-color:var(--wp-admin-theme-color);
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
}

.editor-text-editor__body{
  margin-left:auto;
  margin-right:auto;
  max-width:1080px;
  padding:0 12px 12px;
  width:100%;
}
@media (min-width:960px){
  .editor-text-editor__body{
    padding:0 24px 24px;
  }
}

.editor-text-editor__toolbar{
  background:#fffc;
  display:flex;
  left:0;
  padding:4px 12px;
  position:sticky;
  right:0;
  top:0;
  z-index:1;
}
@media (min-width:600px){
  .editor-text-editor__toolbar{
    padding:12px;
  }
}
@media (min-width:960px){
  .editor-text-editor__toolbar{
    padding:12px 24px;
  }
}
.editor-text-editor__toolbar h2{
  color:#1e1e1e;
  font-size:13px;
  line-height:36px;
  margin:0 0 0 auto;
}

.editor-visual-editor{
  align-items:center;
  background-color:#ddd;
  display:block;
  position:relative;
}
.editor-visual-editor.is-resizable{
  max-height:100%;
}
.editor-visual-editor.has-padding{
  padding:24px 24px 0;
}
.editor-visual-editor.is-iframed{
  overflow:hidden;
}
.editor-visual-editor .components-button{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:13px;
  padding:6px 12px;
}
.editor-visual-editor .components-button.has-icon,.editor-visual-editor .components-button.is-tertiary{
  padding:6px;
}